#
# spec file for package python-tqdm
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
%global flavor test%{nil}
%if "%{flavor}" == "test"
%define test 1
%define suffix -test
%bcond_without test
%else
%define suffix %{nil}
%bcond_with test
%endif
Name:           python-tqdm%{suffix}
Version:        4.31.1
Release:        2.10
Summary:        An extensible progress meter
License:        MPL-2.0 AND MIT
Group:          Development/Languages/Python
URL:            https://github.com/tqdm/tqdm
Source:         https://files.pythonhosted.org/packages/source/t/tqdm/tqdm-%{version}.tar.gz
BuildRequires:  %{python_module rpm-macros}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module jupyter_ipython}
BuildRequires:  %{python_module jupyter_ipywidgets}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module tqdm}
# /SECTION
%endif
%python_subpackages

%description
tqdm lets you output a progress meter from within loops by wrapping
any iterable with "tqdm(iterable)".
tqdm's overhead is one order of magnitude less than python-progressbar
and does not require ncurses.

%prep
%setup -q -n tqdm-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_clone -a %{buildroot}%{_bindir}/tqdm
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if !%{with test}
%post
%{python_install_alternative tqdm tqdm.1}

%postun
%python_uninstall_alternative tqdm
%endif

%if %{with test}
%check
%{python_expand PYTHONPATH=%{$python_sitelib}
nosetests-%%{$python_bin_suffix} --ignore-files="tests_perf\.py" --ignore-files="tests_synchronisation\.py" tqdm/
}
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst logo.png
%doc examples/
%license LICENCE
%dir %{python_sitelib}/tqdm
%dir %{python_sitelib}/tqdm-%{version}-py%{py_ver}.egg-info
%{python_sitelib}/tqdm/*
%{python_sitelib}/tqdm-%{version}-py%{py_ver}.egg-info/*
%python_alternative %{_bindir}/tqdm
%endif

%changelog
* Sat Feb 16 2019 arun@gmx.de
- update to version 4.31.1:
  * fix file.encoding==None caused by #598 (#673 -> #676)
    + add tests
  * tidy code, update authors and tests
    + add setup.py test to CI
- changes from version 4.31.0:
  * Write bytes to stdout/stderr in py2
    (https://bugs.python.org/issue21363, #589 -> #598)
    + Add write_bytes parameter for py2/3 default override
  * support custom bar characters vias ascii parameter (#223 -> #227)
    + implement, document and test custom bar spinners
  * support custom bar_format with unknown total (#282 -> #284)
  * fix TypeError when unit_scale and unknown total
  * document format_dict
  * expose elapsed_s, remaining_s to bar_format
  * add unit option to bar_format (#368)
  * auto README.rst generation framework
    + add notes in CONTRIBUTING.md
  * update tests
  * update documentation
  * misc code tidy
- changes from version 4.30.0:
  * avoid moving when leave=False
  * generalise nested bar tests
  * add display() helper function
  * add and expose format_dict (#562, #482, #494, #656)
    + allow arbitrary keyword arguments for format_meter
    + document format_dict overriding
    + add tests for overriding
    + related: #660 #172 #587
  * add and tidy developer documentation
  * fix py3 CLI pipe decoding error (#663)
  * framework overhaul (developing, testing, Travis CI updates)
  * tidy code and style (flake8)
  * setup.py refactor
    + setup.py make
  - add support for multi-line commands
  - tidy and efficiency
    + replace setup.py's built-in make -> py-make>=0.1.9 (#290)
    + add requirements-dev.txt and extras_require[dev]
  * add, update and tidy tests
  * include interactive Jupyter demonstration (#652 -> #659)
  * update documentation
    + add FAQ about py2 pipes (#359)
    + add badges
    + update examples
    + update authors
- changes from version 4.29.1:
  * fix classmethod lock bug (#617: #457 -> #658)
  * add unit test to prevent regression
- changes from version 4.29.0:
  * Avoid global multiprocessing locks (#611 -> #617)
  * Add support for infinite iterables (#651)
  * Fix missing attr pos when used in multi-threaded environment
    (#573)
  * Do not join TMonitor if it is the current thread (#613 -> #641)
  * Add OpenBSD NIX support (#638)
  * Unit tests, general documentation fixes and tidying (e.g. #642)
  * CI travis improvements
    + py37-dev -> py37 (#622)
    + fix py26
* Tue Feb 12 2019 mcepl@suse.com
- Remove installed files after running the testsuite
* Sat Feb  9 2019 mcepl@suse.com
- Switch to multibuild (with separate test) to avoid large
  dependencies on the main package.
* Mon Dec 31 2018 tbechtold@suse.com
- update to 4.28.1:
  * tqdm.main(): expose argv
  * cli: add working `--manpath`
  * fix CLI:--manpath not found issue
  * update .gitattributes
  * CLI unit tests
  * remove deprecated dist options
  * add missing auto submodule
  * PyPI fix
  * remove man page from distribution
  * cli:add `--man_path` option
* Wed Oct 17 2018 arun@gmx.de
- update to version 4.27.0:
  * fix str.isnumeric #605
  * fix WeakSet KeyError #548, #553, #596 -> #607
  * stop tqdm_notebook description truncation #582 -> #599
  * include unit_scale for rate #608
  * add auto -> nowarning autonotebook
  * add better postfix numeric formatting #621
  * minor refactoring #609 -> #616
  * update documentation
  * add unit tests
  * fix py26 CI
* Sun Sep 16 2018 arun@gmx.de
- update to version 4.26.0:
  * fix smoothing (#566 -> #601)
  * pandas updates
    + address the FutureWarning in pandas, drop pandas test in py34,
    add in py37 (#603)
    + support pandas axis='index' or 'columns' (#570)
  * minor documentation updates (#597, #600, #606)
    + developer notes
* Tue Aug 28 2018 tchvatal@suse.com
- Reenable testsuite
* Sat Aug 25 2018 arun@gmx.de
- specfile:
  * remove devel for noarch package
  * make %%files section more specific
- update to version 4.25.0:
  * stop monitor on shutdown (#571, #572)
  * fix find_packages() for submodules (#593)
    + properly add autonotebook (#586, 1cf3393)
  * ignore ANSI escape codes in the bar length calculation (#450, #591
  - > #592)
  * update documentation (#243)
* Tue Aug  7 2018 toddrme2178@gmail.com
- update to 4.24.0
  * autonotebook submodule for automatic selection of notebook/CLI bar (#443, #508)
    > update/add pandas() example documentation (#474)
  * NameError:IntProgress changed to a more helpful ImportError (#187, #451, #558)
  * support bool() cast when disable=True (#574)
  * fix format_sizeof hundreds rounding (#579 -> #581)
  * ensure URLs in documentation are secure (https)
* Sat Jul 14 2018 arun@gmx.de
- specfile:
  * removed patch support_pandas_23_groupby.patch (included upstream)
  * always run tests
- update to version 4.23.4:
  * Support pandas 0.23.0 core.groupby module layout (#555 -> #554)
  * Add python_requires to help pip (#557)
  * minor maintenance updates
    + CI updates: drop travis py33 due to tox (tox-dev/tox#648)
    + minor code tidy
* Thu May 17 2018 toddrme2178@gmail.com
- update to version 4.23.3
  * suppress warning
  * update .github things
- update to version 4.23.2
  * minor import syntax fix #496
  * re-fix nested overlaps #477
  * update documentation and examples
  * code tidy and abstraction
- update to version 4.23.1
  * fix AttributeErrors (#546)
    >   pos on initialisation (#323, #510 -> #544)
    >   fp on write() (#383)
  * fix py34 CI
  * update documentation
- update to version 4.23.0
  * Fix disable=True whereiterable has no len() and is not None (#539)
  * Add ncols to specify tqdm_notebook bar width (#276 -> #292)
  * allow custom pandas total (#364 -> #535)
  * Add progress_apply for pandas.(Series|DataFrame).(rolling|expanding) (#530 -> #537)
  * unit tests, pep8 tidy
  * postfix non-dict documentation note
- update to version 4.22.0
  * allow direct non-string assignment to postfix member (lists, dicts, etc) (#382 -> #534)
  * documentation updates
  * unit tests
- update to version 4.21.0
  * fix #532 write() with manual position
    >   more robust free position finding
  * add TqdmWarning base class
  * fix GUI __del__()
    >   add TqdmExperimentalWarning
  * add, tidy & fix unit tests
  * documentation
    >   wiki release notes
    >   update contributors
    >   fix 7zx example
- update to version 4.20.0
  * pandas wrapper: remove *args and add better total handling (#244, #299, #322, #366 -> #524)
  * document windows unicode know issues (#454)
  * suppress RuntimeError: Set changed size during iteration -> TqdmSynchronisationWarning
- update to version 4.19.9:
  * fix monitor thread termination and update tests
- Add support_pandas_23_groupby.patch
  * Fix for pandas 0.23.0 support
  * See: https://github.com/tqdm/tqdm/pull/554
* Sat Mar 17 2018 arun@gmx.de
- update to version 4.19.8:
  * TqdmMonitorWarning
  * warnings.warn
  * log.info
  * abstract and no-raise monitor error
* Sat Mar 17 2018 arun@gmx.de
- update to version 4.19.7:
  * fix: Avoid manipulating uninitialized instances on monitoring
    thread.
* Thu Mar  1 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 4.19.6:
  * CLI improvements
    + --bytes implies --unit B --unit_scale --unit_divisor 1024 (#503)
    + allow hyphens in CLI arguments (#511)
  * synchronisation: fix for sem_open on aarch64 (#513)
  * framework update
    + CI/tests, year 2018, py37, badges, documentation
* Sun Dec 10 2017 arun@gmx.de
- update to version 4.19.5:
  * multiprocess/lock fixes (#457)
  * set_description in notebook (#345 -> #475)
  * minor tidy (#476)
  * documentation updates
* Sun Oct 15 2017 arun@gmx.de
- update to version 4.19.4:
  * fix Lock:NotImplementedError on certain systems (#466 -> #468)
  * use recursive locks (#469 -> #468)
    + fix deadlocks
  * tidy (#448)
  * flush() on moveto() (#398 -> #399, #420, #467)
  * update tests and benchmarks
- changes from version 4.19.3:
  * no changelog available
* Tue Oct 10 2017 arun@gmx.de
- specfile:
  * added man page, fixed path for man-page in setup.py
  * added fdupes
- update to version 4.19.2:
  * flush() on refresh() (#459 from #317)
  * status printer updates (#331)
    + use sp() in refresh()
    + remove redundant clear():nomove=False
  * misc minor documentation updates
  * unit tests
- changes from version 4.19.1:
  * rate_(no)inv(_fmt) (#72, b228bc3)
  * __repr__() tidy (#389)
  * fix write() before initialisation AttributeError: _lock (#457)
  * man pages
  * documentation updates
* Fri Oct  6 2017 jengelh@inai.de
- Redo description with sensible content.
* Tue Oct  3 2017 arun@gmx.de
- update to version 4.18.0:
  * Thread safety! (#285 -> #291 -> #329, #407, #417)
  * Ease redirection of sys.stdout/stderr (#422)
  * Minor internal stream bugfix (#439)
  * AttributeError fixes (#323, #324, #418)
  * Related to:
    + Misc bugs (#334)
    + concurrent.futures (#97)
    + Multi-tqdm (#143)
    + flush() and refresh() (#331)
    + Newline on refresh() (#361)
    + Nested trees (#384)
    + Manually positioned nested bars clearing (#385)
* Sun Sep 24 2017 arun@gmx.de
- update to version 4.17.1:
  * __repr__() bugfix
  * better unicode detection
  * initialise `n` even when disabled
- changes from version 4.17.0:
  * easier redirect of stdout (#426 -> #431)
    + cls.external_write_mode() @contextmanager
  * refresh=True for set_description/update(_str) (#317 -> #377)
- changes from version 4.16.0:
  * more formatting control (#347 -> #362)
    + set_postfix_str(), set_description_str()
    + move ": " to bar_format
    + complements #266, #270
  * better CLI support (e.g. hyphenated paths) (#421 #423 -> #424)
  * more unit tests (#411)
    + upgrade to pypy2/3-5.8.0
    + add py37-dev
  * doc updates
- changes from version 4.15.0 :
  * minor fixes (#395)
  * minor documentation updates (#400, #401, #412)
  * better pandas support (#351 -> #409)
  * Jupyter notebook fix (#352, #369 -> #373, #405)
  * optimise setcheckinterval/setswitchinterval (#376)
  * add unit_scale (#273, #295 -> #378)
* Wed Jul  5 2017 sebix+novell.com@sebix.at
- upgrade specfile to singlespec
- upgrade to 4.14.0
* Wed Mar  1 2017 toddrme2178@gmail.com
- Update to 4.11.2
  * thread safety #332
  * address DeprecationWarning #319 -> #326
  * version extra #328 -> #330
    + security fix
    + add non-master branch name
    + Fixes BNC#1017485
    + Fixes CVE#CVE-2016-10075
  * minor safety
  * minor documentation and comments
- Update to 4.11.1
  * Officially support Python 3.6, addressing #333
- Update to 4.11.0
  * postfix argument added #266->#270
  * fix tests for
    + numpy #272->#302
    + PyPy3 #318->#325
  * 7z extraction example script
  * new logo #315
  * hit counter with logo colours and stats
  * documentation updates
  * safer setup.py Makefile emulation
  * better github contributions integrations and Code of Conduct #310
- update to version 4.10.0:
  * fix maxinterval to adjust miniters to mininterval #249
  * minor bugfixes (eg #288)
  * misc optimisations, unit tests, and benchmarks (eg #298)
  * documentation updates
- update to version 4.9.0:
  * monitoring thread to automatically to adjust miniters and avoid
    exceeding maxinterval
    + test race conditions
    + kill on KeyboardInterrupt + instant refresh
    + low performance overhead, option to disable
  * new CLI argument: --bytes to count chars
  * disable automatically on non-TTY (#281)
  * fixed refresh() and clear() if disabled (#286)
  * misc fixes
  * documentation
  * unit tests
  * optimisations, style fixes
  * codacy badge
  * safety and warning suppression
  * ignore coverall failures (#283)
  * fix broken link in README (#262)
  * Fix time() in refresh() + avoid write() races (#264)
  * Fix __repr__() #269
  * Fix update(0) causing ZeroDivisionError (on first call) #268
  * Faster simple bar for perf test (#257)
  * cleaner tqdm_notebook exit when not run in a notebook (#267)
  * Disable coveralls because of duplicate comments on github (#263)
  * Migrate codecov config -> codecov.yml
* Mon Sep 19 2016 toddrme2178@gmail.com
- update to version 4.8.4:
  * 14%% overhead reduction
  * fix exception when closing tqdm_notebook without a total
  * support more pandas modules
  * pandas.Series.progress_map
  * pandas.DataFrame.progress_applymap
  * Panel.progress_apply
  * PanelGroupBy.progress_apply
  * GroupBy.progress_aggregate
  * GroupBy.progress_transform
  * faster CI builds
  * misc documentation update and link to wiki
- update to version 4.8.3:
  (no changelog available)
- update to version 4.8.2:
  * custom tqdm warning/exceptions
  * tests now multiprocessed and include pandas
- update to version 4.8.1:
  * custom tqdm warning/exceptions
  * tests now multiprocessed and include pandas
- update to version 4.8.0:
  * tqdm.pandas classmethod replaces tqdm_pandas function (deprecated)
  * ipython aliased imports fixes
  * write without any instances
  * readme update
  * examples update
  * test fixes and updates
- update to version 4.7.6:
  * numpy len support, addressing #185
- update to version 4.7.5:
  * spring clean (mostly pragma)
  * addresses #182
  * series len, tests
  * disable support (fixes #184), fkake8 fixes
- update to version 4.7.4:
  * pandas.DataFrame.apply support
  * tqdm_notebook.write()
  * tqdm_gui.write()
  * misc notebook fixes
  * delay notebook imports (>80%% reduction in import time when unused)
  * optional colorama only on windows
  * documentation tidy
  * more & faster tests
- update to version 4.7.1:
  * pandas.DataFrame.apply support
- update to version 4.7.0:
  * CLI custom delimiter support
  * More robust CLI argument parsing
  * either one or two - preceding kwargs (eg -ascii or --ascii)
  * no positional args (so no need to quote multi-word -desc for
    example)
  * bool kwargs with implicit value=True still supported
  * optional = sign after kwargs
  * tests
  * doc updates, badges
  * pyversions, doi, licence, github
- update to version 4.6.2:
  * Fix warnings due to IPython/Jupyter widget
- update to version 4.6.1:
  * add IPython/Jupyter support
  * fix {bar} length breaking display when using custom bar_format
  * add a no inversion rate formatting for bar_format (i.e., always
    show it/s and never s/it)
- update to version 4.6.0:
  * (no changelog availabel)
- update to version 4.5.0:
  * print messages within (nested) loops using tqdm.write(...)
- update to version 4.4.3:
  * remove docopt dependency for CLI
  * re-added update(0) ability to trigger refresh
  * minor fixes
  * re-added (OSI approved) licence to source
  * dev versioning auto-fallback
  * slight speed optimisation
  * tests
  * documentation
- update to version 4.4.2:
  * no changelog available
- update to version 4.4.1:
  * remove "dumb binaries" from build, coverage
- update to version 4.4.0:
  * modularise
- update to version 4.3.0:
  * fix_position
  * tidy
- update to version 4.2.0:
  * licencizors
- update to version 4.1.0:
  * compat-fixes
- update to version 4.0.0:
  * automate nested
    + deprecate nested
    + add manual override control with position
  * documentation and example updates, coverage and tests
  * make leave==True by default (was False)
* Mon Feb  1 2016 arun@gmx.de
- update to version 3.8.0:
  * update(n<1) raises error
  * sanitise and update examples and README
  * fix setup.py encoding error
  * remove py32 from Travis
  * changelog more accessible from README
* Wed Jan 20 2016 toddrme2178@gmail.com
- Initial version
